/**
 * @file Type definitions for types from 'macaroons.js' file
 */
/// <reference types="node" />
/**
 * @typedef {Object} CaveatPacketInterface
 * @property {CaveatPacketType} type
 * @property {Buffer} rawValue
 * @property {string} valueAsText
 */
export interface CaveatPacketInterface {
    type: CaveatPacketType;
    rawValue: Buffer;
    valueAsText: string;
    getRawValue: () => Buffer;
    getValueAsText: () => string;
}
export declare enum CaveatPacketType {
    location = 0,
    identifier = 1,
    signature = 2,
    cid = 3,
    vid = 4,
    cl = 5
}
/**
 * @typedef {Object} MacaroonInterface
 * @property {string} location
 * @property {string} identifier
 * @property {string} signature
 * @property {Buffer} signatureBuffer
 * @property {CaveatPacketType[]} caveatPackets
 */
export interface MacaroonInterface {
    location: string;
    identifier: string;
    signature: string;
    signatureBuffer: Buffer;
    caveatPackets: CaveatPacketInterface[];
    serialize: () => string;
    inspect: () => string;
    createKeyValuePacket: (type: CaveatPacketType, value: string) => string;
    createCaveatPackets: (caveats: CaveatPacketInterface[]) => string;
}
